/* 
    Copyright (C) 2006 by Gary A. Morris
    
    This file is part of CAN_decoder - http://mggm.net/prius/candecoder.html

    CAN_decoder is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    CAN_decoder is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with CAN_decoder; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

#ifndef __CANDataMgr_h__
#define __CANDataMgr_h__

#include <vector>
#include <cstdio>
#include "FieldData.h"

class CANDataMgr {
    public:
        //-------------------------
        //  type definitions
        //-------------------------
        enum FieldIndexType {
            timestamp = 0,  // start field ids at zero
            voltage,
            soc,
            amps,
            maxChargeCurrent,
            maxDischargeCurrent,
            minBattTemp,
            maxBattTemp,
            speed,
            speedometer,
            speedRelated,
            frontLeft,
            frontRight,
            rearLeft,
            rearRight,
            iceRPM,
            iceTemp,
            waterTemp,
            sideAccel,
            sideAccel2,
            fwdAccel,
            fwdAccel2,
            steering,
            gasPedal,
            brakePedal,
            brakesPressed,
            shiftLever,
            evMode,
            cruiseControl,
            lights,
            fuelInj,
            fuelFlow,
            VVTi,
            gasGauge,
			kmlMPGnum,
            NFIELDS         // number of fields defined (assuming first field is 0)
        };   
           
        typedef unsigned int FieldIdType;
           
        //-------------------------  
        //  constructors
        //-------------------------  
        CANDataMgr(const Globals::UnitsType units);
        
        //-------------------------  
        //  methods
        //-------------------------  
        // update the current value of a field in our records,
        // if we have all the fields a line will be written out
        // to the file.
        void updateField(FieldIdType fieldId, double fieldValue);
        
        // update the current value of a field in our records,
        // if we have all the fields a line will be written out
        // to the file.
        void updateField(FieldIdType fieldId, const std::string& fieldValue, bool addQuotes);
        
        // clear all stored field values
        void clearFields();     // used to clear the field data array
        
        // output all stored field values
        void outputFields(std::FILE* outFile);    // output field data to a file
        
    //-----------------------------------------------
    //  private part
    //-----------------------------------------------
    private:        
        FieldData CANFields[NFIELDS];
        
        bool headerPrinted;     // indicates if the CSV header line was printed
        
};

#endif
