/* 
    Copyright (C) 2006 by Gary A. Morris
    
    This file is part of CAN_decoder - http://mggm.net/prius/candecoder.html

    CAN_decoder is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    CAN_decoder is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with CAN_decoder; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

	Modified by Jay Groh to work with the V4 CAN-View. http://www.jaygroh.com
*/

#ifndef __CAN_packets_h__
#define __CAN_packets_h__

#include <cstdio>
#include "CANDataMgr.h"


#define PACKETSIZE 11   // size of packets from CAN-View in raw data mode
#define HEADERSIZE 3    // number of bytes in id/length part of packet
#define DATAOFFSET HEADERSIZE // offset from packet start to actual data

#define rINVALID -2      // return value indicates invalid result
#define rEOF     -3      // return value indicates end of files
#define rFAILED  -1      // return value indicates failure of operation
#define rSUCCESS  0      // return value indicates successful operation

const int START_PACKET_ID = 0x0020;
const int END_PACKET_ID   = 0x056D;				// Changed from 0602 to 056D because the V4 CAN-View stops at 056D

const int MAX_PACKET_ID   = 0xFFFF;
const int MIN_PACKET_ID   = 0x0000;

typedef short          Signed16Type;
typedef unsigned short Unsigned16Type;

typedef Unsigned16Type PacketIdType;
typedef unsigned char  PacketLenType;        

class CANPackets {
    public:
        typedef unsigned char BufferType;

        Signed16Type   getSigned12  (const BufferType* bytes) const;
        Signed16Type   getSigned16  (const BufferType* bytes) const;
        Unsigned16Type getUnsigned16(const BufferType* bytes) const;

        // extracts valid data from a packet and stores it
        void decodePacket(const BufferType* dataP,
                          const PacketIdType packetId,
                          CANDataMgr& data) const;

        // returns packet id if valid packet found, otherwise
        // returns rFAILED if no valid packet was found.
        PacketIdType isPacket(const BufferType* bufP) const;  

        // prints packet data for debugging
        void printPacket(const PacketIdType id,
                         const PacketLenType len,
                         const BufferType* bytes) const;

        // convert speed in km/h into desired units based
        // on global units flag
        double CANPackets::convertSpeed(const double speedKMH) const;
		
		// convert speed in L/hr into desired units based
        // on global units flag
        double CANPackets::convertFuel(const double fuelLiters) const;
        
        // convert temp in degrees C into desired units based
        // on global units flag
        long CANPackets::convertTemp(const double degreesC) const;
        
};

#endif