/* 
    Copyright (C) 2006 by Gary A. Morris
    
    This file is part of CAN_decoder - http://mggm.net/prius/candecoder.html

    CAN_decoder is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    CAN_decoder is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with CAN_decoder; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

#include <cstdio>
#include "FieldData.h"

FieldData::FieldData() :
    fieldValid(false) {
}

// initialize field
void FieldData::init(const std::string& theFieldName, 
                     const long theFieldMin,
                     const long theFieldMax) {
    fieldName  = theFieldName;
    fieldValid = false;
    minValue   = theFieldMin;
    maxValue   = theFieldMax;
}

// check a long value to see if it is within the min/max,
bool FieldData::isInRange(const long value) const {
    return value >= minValue && value <= maxValue;
}

bool FieldData::isInitialized() const {
    return fieldName.length() > 0;
}

bool FieldData::isValid() const {
    return fieldValid;
}

const std::string& FieldData::name() const {
    return fieldName;
}

void FieldData::setName(const std::string& newName) {
    fieldName = newName;
}        

const std::string& FieldData::value() const {
    return fieldValue;
}

void FieldData::value(const std::string& newValue) {
    fieldValue = newValue;
    fieldValid = true;
}

void FieldData::clearValue() {
    fieldValid = false;
}