/* 
    Copyright (C) 2006 by Gary A. Morris
    
    This file is part of CAN_decoder - http://mggm.net/prius/candecoder.html

    CAN_decoder is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    CAN_decoder is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with CAN_decoder; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

#ifndef __FieldData_h__
#define __FieldData_h__

#include <string>

const long MIN_LONG_VALUE = 0x80000000;
const long MAX_LONG_VALUE = 0x7FFFFFFF;

class FieldData {
    public:
        // default constructor
        FieldData();

        // initialize field
        void init(const std::string& theFieldName, 
                  const long theFieldMin = MIN_LONG_VALUE, 
                  const long theFieldMax = MAX_LONG_VALUE);

        // check to see if a field has been initialized
        bool isInitialized() const;
        
        // check to see if a field has valid data
        bool isValid() const;
        
        // check a long value to see if it is within the min/max,
        bool isInRange(const long value) const;
        
        // get the name of the field
        const std::string& name() const;

        // get the value of the field
        const std::string& value() const;
        
        // set the value of a field
        void value(const std::string& newValue);

        // set the name of a field
        void setName(const std::string& newName);
        
        // clear out the value
        void clearValue();
        
    private:
        std::string fieldName;   // name of each field (for the csv file header)
        std::string fieldValue;  // value of this field in current packet
        bool        fieldValid;  // indicates if fieldValue has valid data

        long minValue;    // minimum valid value for this field
        long maxValue;    // maximum valid value for this field
     
};

#endif